import type { ExtensionTheme } from './base';
/**
 * CSS Variables interface for customizing the file explorer's appearance.
 * These variables can be overridden by users to customize the look and feel.
 *
 * @example
 * ```ts
 * createCompleteTheme({
 *   variables: {
 *     '--cm-ext-explorer-text': '#e1e1e3',
 *     '--cm-ext-explorer-bg-hover': 'rgba(255, 255, 255, 0.05)',
 *   }
 * })
 * ```
 */
export interface ExplorerThemeVariables {
    '--cm-ext-explorer-text': string;
    '--cm-ext-explorer-text-header': string;
    '--cm-ext-explorer-border': string;
    '--cm-ext-explorer-bg-hover': string;
    '--cm-ext-explorer-bg-selected': string;
    '--cm-ext-explorer-border-selected': string;
    '--cm-ext-explorer-font-size': string;
    '--cm-ext-explorer-font-weight': string;
    '--cm-ext-explorer-header-font-size': string;
    '--cm-ext-explorer-header-font-weight': string;
    '--cm-ext-explorer-header-letter-spacing': string;
}
export declare const explorerThemeVariables: ExplorerThemeVariables;
/**
 * Explorer theme configuration.
 *
 * Public CSS Classes for Styling:
 * - .cm-ext-explorer-content: Main container of the file explorer
 * - .cm-ext-explorer-list: List container for files/directories
 * - .cm-ext-explorer-item: Individual file/directory items
 * - .cm-ext-explorer-caret: Directory expand/collapse carets
 *
 * Each of these classes can be styled using the CSS variables defined in ExplorerThemeVariables.
 */
export declare const explorerTheme: ExtensionTheme;
