import type { ExtensionTheme } from './base';
/**
 * CSS Variables interface for customizing the sidebar's appearance.
 * These variables can be overridden by users to customize the look and feel.
 *
 * @example
 * ```ts
 * createCompleteTheme({
 *   variables: {
 *     '--cm-ext-sidebar-bg': '#21222c',
 *     '--cm-ext-sidebar-border': 'rgba(255, 255, 255, 0.2)',
 *   }
 * })
 * ```
 */
export interface SidebarThemeVariables {
    '--cm-ext-sidebar-bg': string;
    '--cm-ext-sidebar-border': string;
    '--cm-ext-sidebar-resize-hover': string;
    '--cm-ext-sidebar-resize-active': string;
    '--cm-ext-sidebar-width': string;
    '--cm-ext-sidebar-resize-handle-width': string;
    '--cm-ext-sidebar-min-width': string;
    '--cm-ext-sidebar-max-width': string;
}
export declare const sidebarThemeVariables: SidebarThemeVariables;
/**
 * Sidebar theme configuration.
 *
 * Public CSS Classes for Styling:
 * - .cm-ext-sidebar: Main container of the sidebar
 * - .cm-ext-sidebar-panel: Panel container within the sidebar
 * - .cm-ext-sidebar-resize: Resize handle for the sidebar
 *
 * Each of these classes can be styled using the CSS variables defined in SidebarThemeVariables.
 */
export declare const sidebarTheme: ExtensionTheme;
